// main32.cc is a part of the PYTHIA event generator.
// Copyright (C) 2015 Torbjorn Sjostrand.
// PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
// Please respect the MCnet Guidelines, see GUIDELINES for details.

// This is a sample program showing Alpgen- or Madgraph-style MLM matching
// for Madgraph LHEF or native Alpgen format event files.
//
// Please see the 'Jet Matching Style' manual page for a description of the
// parameters and user options.

// Includes and namespace
#include "Pythia8/Pythia.h"
#include "Pythia8Plugins/CombineMatchingInput.h"
#include <fstream>
using namespace Pythia8;

//==========================================================================

int main() {

 // Generator and read in commands.
  Pythia pythia;
  pythia.readFile("main104.cmnd",0);

  // Extract settings to be used in the main program.
  int nEvent = pythia.mode("Main:numberOfEvents");
  int nSubrun = pythia.mode("Main:numberOfSubruns");
  
  // Create UserHooks pointer. Stop if it failed. Pass pointer to Pythia.
  CombineMatchingInput combined;
  UserHooks* matching = combined.getHook(pythia);
  if (!matching) return 1;
  pythia.setUserHooksPtr(matching);

  SlowJet Jets(-1, 0.4, 20.0, 4.0); 
  ofstream histograms;
  histograms.open("histograms.dat",ios::out);
  
  Hist pT1("pT, subrun1", 100, 0., 200.);
  Hist pT2("pT, subrun2", 100, 0., 200.);
  Hist pT3("pT, subrun3", 100, 0., 200.);
  Hist pTsum("pT, summed over all subruns", 100, 0., 200.);
  for (int iSubrun = 1; iSubrun <= nSubrun; ++iSubrun) {

    // Read in subrun-specific data from main13.cmnd.
    pythia.readFile( "main104.cmnd", iSubrun);

    // Initialize generator.
    pythia.init();

    // Begin infinite event loop - to be exited at end of file.
    for (int iEvent = 0; ; ++iEvent) {

      // Generate next event.
      if (!pythia.next()) {

        // Leave event loop if at end of file.
        if (pythia.info.atEndOfFile()) break;

      }
      // Event analysis goes here.
      Jets.analyze(pythia.event);
      double pt = (Jets.sizeJet() > 2 ) ? Jets.pT(2) : 0.0; 
      if (iSubrun == 1 ) pT1.fill(pt);
      if (iSubrun == 2 ) pT2.fill(pt);
      if (iSubrun == 3 ) pT3.fill(pt);
      pTsum.fill(pt);
    }
    // End of event loop.
	
    pythia.stat();

  }

  // Final statistics and done.
  cout << pT1 << pT2 << pT3 << pTsum;
  pT1.table(histograms);
  histograms << endl << endl;
  pT2.table(histograms);
  histograms << endl << endl;
  pT3.table(histograms);
  histograms << endl << endl;
  pTsum.table(histograms);
  histograms << endl << endl;
  
  delete matching;
  histograms.close();

  return 0;
}
